@@ -36,6 +36,7 @@ typedef struct _TangleActor TangleActor;
 typedef struct _TangleActorPrivate TangleActorPrivate;
 
 #include "tangle-event.h"
+#include "tangle-transition.h"
 
 /**
  * TangleActor:
@@ -53,7 +54,7 @@ struct _TangleActor {
 typedef struct _TangleActorClass {
 	ClutterActorClass parent_class;
 	
-	ClutterAnimation* (*animate_transition)(TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box);
+	ClutterTimeline* (*animate_transition)(TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box);
 	void (*transition_completed)(TangleActor* actor, ClutterActorBox* old_box, ClutterActorBox* current_box);
 	void (*show_completed)(TangleActor* actor, ClutterActorBox* current_box);
 	void (*get_preferred_width)(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
@@ -75,8 +76,17 @@ GType tangle_actor_get_type (void) G_GNUC_CONST;
 
 ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, const gchar* first_property_name, ...);
 ClutterAnimation* tangle_actor_animate_with_timeline(TangleActor* actor, gulong mode, ClutterTimeline* timeline, const gchar* first_property_name, ...);
+ClutterAnimation* tangle_actor_animatev(TangleActor* actor, gulong mode, guint duration, gint n_properties, const gchar* const property_names[], const GValue* property_values);
+gboolean tangle_actor_stop_animation(TangleActor* actor, ClutterAnimation* animation);
 
+TangleTransition* tangle_actor_get_transition(TangleActor* actor);
+void tangle_actor_set_transition(TangleActor* actor, TangleTransition* transition);
 gboolean tangle_actor_should_transition_scale_children(TangleActor* actor);
+void tangle_actor_apply_transition_scale(TangleActor* actor);
+void tangle_actor_get_transition_move(TangleActor* actor, gfloat* x_return, gfloat* y_return);
+void tangle_actor_set_transition_move(TangleActor* actor, gfloat x, gfloat y);
+void tangle_actor_get_transition_scale(TangleActor* actor, gdouble* x_return, gdouble* y_return);
+void tangle_actor_set_transition_scale(TangleActor* actor, gdouble x, gdouble y);
 
 void tangle_actor_show(TangleActor* actor);
 void tangle_actor_hide_animated(TangleActor* actor);
