@@ -125,13 +125,17 @@ void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActo
         
 	if (button->priv->normal_background_actor != actor) {
 		if (button->priv->normal_background_actor) {
+			clutter_actor_unparent(button->priv->normal_background_actor);
 			g_object_unref(button->priv->normal_background_actor);
 		}
 		button->priv->normal_background_actor = actor;
-		g_object_ref_sink(button->priv->normal_background_actor);
+		if (button->priv->normal_background_actor) {
+			g_object_ref_sink(button->priv->normal_background_actor);
+			clutter_actor_set_parent(button->priv->normal_background_actor, CLUTTER_ACTOR(button));	
+		}
 
 		if (!button->priv->active || !button->priv->interactive_background_actor) {
-			tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+			tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 		}
 	}
 }
@@ -149,17 +153,21 @@ void tangle_button_set_interactive_background_actor(TangleButton* button, Clutte
 
 	if (button->priv->interactive_background_actor != actor) {
 		if (button->priv->interactive_background_actor) {
+			clutter_actor_unparent(button->priv->interactive_background_actor);
 			g_object_unref(button->priv->interactive_background_actor);
 			had_interactive_background_actor = TRUE;
 		}
 		button->priv->interactive_background_actor = actor;
-		g_object_ref_sink(button->priv->interactive_background_actor);
+		if (button->priv->interactive_background_actor) {
+			g_object_ref_sink(button->priv->interactive_background_actor);
+			clutter_actor_set_parent(button->priv->interactive_background_actor, CLUTTER_ACTOR(button));	
+		}
 
 		if (button->priv->active) {
 			if (button->priv->interactive_background_actor) {
-				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
 			} else if (had_interactive_background_actor) {
-				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 			}
 		}
 	}
@@ -178,17 +186,21 @@ void tangle_button_set_selected_background_actor(TangleButton* button, ClutterAc
 
 	if (button->priv->selected_background_actor != actor) {
 		if (button->priv->selected_background_actor) {
+			clutter_actor_unparent(button->priv->selected_background_actor);
 			g_object_unref(button->priv->selected_background_actor);
 			had_selected_background_actor = TRUE;
 		}
 		button->priv->selected_background_actor = actor;
-		g_object_ref_sink(button->priv->selected_background_actor);
+		if (button->priv->selected_background_actor) {
+			g_object_ref_sink(button->priv->selected_background_actor);
+			clutter_actor_set_parent(button->priv->selected_background_actor, CLUTTER_ACTOR(button));	
+		}
 
 		if (button->priv->selected) {
 			if (button->priv->selected_background_actor) {
-				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
 			} else if (had_selected_background_actor) {
-				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 			}
 		}
 	}
@@ -209,7 +221,13 @@ void tangle_button_set_selected(TangleButton* button, gboolean selected) {
 	
 	if (button->priv->selected != selected) {
 		button->priv->selected = selected;
-		clutter_actor_queue_relayout(CLUTTER_ACTOR(button));
+		if (!button->priv->active) {
+			if (button->priv->mode == TANGLE_BUTTON_SELECTABLE && button->priv->selected && button->priv->selected_background_actor) {
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
+			} else {
+				tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+			}
+		}
 		g_object_notify(G_OBJECT(button), "selected");
 	}
 }
@@ -237,6 +255,24 @@ static gboolean tangle_button_clicked(TangleButton* button) {
 	return FALSE;
 }
 
+static void tangle_button_map(ClutterActor* actor) {
+	TangleButton* button;
+
+	button = TANGLE_BUTTON(actor);
+
+	CLUTTER_ACTOR_CLASS(tangle_button_parent_class)->map(actor);
+
+	if (button->priv->normal_background_actor) {
+		clutter_actor_map(button->priv->normal_background_actor);
+	}
+	if (button->priv->interactive_background_actor) {
+		clutter_actor_map(button->priv->interactive_background_actor);
+	}
+	if (button->priv->selected_background_actor) {
+		clutter_actor_map(button->priv->selected_background_actor);
+	}
+}
+
 static void tangle_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	TangleButton* button;
 	
@@ -328,6 +364,8 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	gobject_class->set_property = tangle_button_set_property;
 	gobject_class->get_property = tangle_button_get_property;
 
+	clutter_actor_class->map = tangle_button_map;
+
 	actor_class->handle_ancestor_event = tangle_button_handle_ancestor_event;
 
 	button_class->clicked = tangle_button_clicked;
@@ -350,7 +388,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	                                                    "Normal background actor",
 	                                                    "The background actor used in normal (noninteractive) state",
 	                                                    CLUTTER_TYPE_ACTOR,
-	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	/**
 	 * TangleClutterActor:interactive-background-actor:
@@ -360,7 +398,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	                                                    "Interactive background actor",
 	                                                    "The background actor used in interactive (interacting) state",
 	                                                    CLUTTER_TYPE_ACTOR,
-	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleClutterActor:selected-background-actor:
 	 */
@@ -369,7 +407,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	                                                    "Selected background actor",
 	                                                    "The background actor used in selected state",
 	                                                    CLUTTER_TYPE_ACTOR,
-	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleButton:selected:
 	 */
@@ -409,7 +447,7 @@ static void start_interacting(TangleButton* button) {
 
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), TRUE);
 	if (button->priv->interactive_background_actor) {
-		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
+		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
 	}
 	button->priv->button_release_event_handler_id = g_signal_connect(clutter_actor_get_stage(CLUTTER_ACTOR(button)), "button-release-event", G_CALLBACK(on_button_release_event), button);
 
@@ -425,9 +463,9 @@ static void end_interacting(TangleButton* button) {
 	
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
 	if (button->priv->mode == TANGLE_BUTTON_SELECTABLE && button->priv->selected && button->priv->selected_background_actor) {
-		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
+		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
 	} else {
-		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 	}
 	if (button->priv->button_release_event_handler_id) {
 		g_signal_handler_disconnect(clutter_actor_get_stage(CLUTTER_ACTOR(button)), button->priv->button_release_event_handler_id);
