@@ -21,6 +21,8 @@
 #define TANGLE_IS_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TANGLE_TYPE_BUTTON))
 #define TANGLE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TANGLE_TYPE_BUTTON, TangleButtonClass))
 
+#define TANGLE_TYPE_BUTTON_MODE (tangle_button_mode_get_type())
+
 typedef struct _TangleButtonPrivate TangleButtonPrivate;
 
 typedef struct _TangleButton {
@@ -37,15 +39,31 @@ typedef struct _TangleButtonClass {
 
 GType tangle_button_get_type(void) G_GNUC_CONST;
 
+typedef enum {
+	TANGLE_BUTTON_CLICKABLE = 0,
+	TANGLE_BUTTON_SELECTABLE
+} TangleButtonMode;
+
+GType tangle_button_mode_get_type(void) G_GNUC_CONST;
 
 ClutterActor* tangle_button_new(void);
 ClutterActor* tangle_button_new_with_background_actor(ClutterActor* normal_background_actor);
 ClutterActor* tangle_button_new_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor);
+ClutterActor* tangle_button_new_selectable(void);
+ClutterActor* tangle_button_new_selectable_with_background_actor(ClutterActor* normal_background_actor);
+ClutterActor* tangle_button_new_selectable_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor, ClutterActor* selected_background_actor);
+
+TangleButtonMode tangle_button_get_mode(TangleButton* button);
+void tangle_button_set_mode(TangleButton* button, TangleButtonMode mode);
+
 ClutterActor* tangle_button_get_normal_background_actor(TangleButton* button);
-ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button);
-TangleAction* tangle_button_get_clicked_action(TangleButton* button);
 void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActor* actor);
+ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button);
 void tangle_button_set_interactive_background_actor(TangleButton* button, ClutterActor* actor);
-void tangle_button_set_clicked_action(TangleButton* button, TangleAction* action);
+ClutterActor* tangle_button_get_selected_background_actor(TangleButton* button);
+void tangle_button_set_selected_background_actor(TangleButton* button, ClutterActor* actor);
+
+gboolean tangle_button_get_selected(TangleButton* button);
+void tangle_button_set_selected(TangleButton* button, gboolean selected);
 
 #endif
