@@ -60,6 +60,18 @@ void tangle_droppable_actor_handle_dropping(TangleDroppableActor* droppable_acto
 	g_signal_emit(droppable_actor, signals[HANDLE_DROPPING], 0, dragging, accepted, &handled);
 }
 
+gboolean tangle_droppable_actor_get_dropping_enabled(TangleDroppableActor* droppable_actor) {
+
+	return droppable_actor->priv->dropping_enabled;
+}
+
+void tangle_droppable_actor_set_dropping_enabled(TangleDroppableActor* droppable_actor, gboolean dropping_enabled) {
+	if (droppable_actor->priv->dropping_enabled != dropping_enabled) {
+		droppable_actor->priv->dropping_enabled = dropping_enabled;
+		g_object_notify(G_OBJECT(droppable_actor), "dropping-enabled");
+	}
+}
+
 static gboolean tangle_droppable_actor_real_is_dragging_droppable(TangleDroppableActor* droppable_actor, TangleDragging* dragging) {
 
 	return TRUE;
