@@ -98,7 +98,7 @@ static void tangle_linear_gradient_paint(ClutterActor* actor) {
 	}
 
 	tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &box);
-	cogl_clip_push(box.x1, box.y1, box.x2 - box.x1, box.y2 - box.y1);
+	cogl_clip_push_rectangle(box.x1, box.y1, box.x2, box.y2);
 	cogl_polygon(TANGLE_LINEAR_GRADIENT(actor)->priv->vertices, 4, TRUE);
 	cogl_clip_pop();
 	
