@@ -13,6 +13,7 @@
 #include <gobject/gvaluecollector.h>
 #include <string.h>
 #include <clutter/clutter.h>
+#include <gmodule.h>
 
 /**
  * SECTION:tangle-misc
@@ -202,3 +203,26 @@ gboolean tangle_signal_accumulator_non_null_handled(GSignalInvocationHint* ihint
 
 	return !object;
 }
+
+gboolean tangle_signal_connect_dynamically(GObject* object, const gchar* signal_name, const gchar* function_name, gpointer user_data) {
+	gboolean retvalue = FALSE;
+	GModule* module = NULL;
+	gpointer function_pointer;
+	
+	if (!g_signal_lookup(signal_name, G_TYPE_FROM_INSTANCE(object))) {
+		g_warning("No such signal: '%s'.", signal_name);
+	} else if (!g_module_supported() || !(module = g_module_open(NULL, 0))) {
+		g_warning("The current platform does not support modules.");
+	} else if (!g_module_symbol(module, function_name, (gpointer*)&function_pointer)) {
+		g_warning("No such function: '%s'", function_name);
+	} else if (!g_signal_connect(object, signal_name, G_CALLBACK(function_pointer), user_data)) {
+		g_warning("Failed to connect a handler function '%s' for signal '%s'.", function_name, signal_name);
+	} else {
+		retvalue = TRUE;
+	}
+	if (module) {
+		g_module_close(module);
+	}
+	
+	return retvalue;
+}
