@@ -105,46 +105,6 @@ void tangle_view_stop_timelines(TangleView* view) {
 	/* TODO: Implement! */
 }
 
-static ClutterAnimation* tangle_view_animate_transition(TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box) {
-	ClutterAnimation* animation = NULL;
-	guint duration;
-	gulong mode;
-	ClutterActor* parent;
-
-	g_object_get(G_OBJECT(actor), "transition-duration", &duration, "transition-mode", &mode, NULL);
-	if (duration && mode) {
-		if (current_box && new_box) {
-			animation = TANGLE_ACTOR_CLASS(tangle_view_parent_class)->animate_transition(actor, current_box, new_box);
-		} else if (current_box) {
-			animation = tangle_actor_animate(actor, mode, duration,
-			                                 "transition-move-x", -(current_box->x2 - current_box->x1) / 4,
-							 "transition-move-y", -(current_box->y2 - current_box->y1) / 4,
-							 "transition-scale-x", 2.0,
-							 "transition-scale-y", 2.0,
-							 "opacity", 0,
-							 NULL);
-		} else if ((parent = clutter_actor_get_parent(CLUTTER_ACTOR(actor))) &&
-		           (!TANGLE_IS_ACTOR(parent) || TANGLE_ACTOR_IS_ALLOCATED(parent))) {
-			g_object_set(G_OBJECT(actor),
-			             "transition-move-x", (new_box->x2 - new_box->x1) / 4,
-				     "transition-move-y", (new_box->y2 - new_box->y1) / 4,
-				     "transition-scale-x", 0.5,
-				     "transition-scale-y", 0.5,
-				     "opacity", 0,
-				     NULL);
-			animation = tangle_actor_animate(actor, mode, duration,
-			                                 "transition-move-x", 0.0,
-							 "transition-move-y", 0.0,
-							 "transition-scale-x", 1.0,
-							 "transition-scale-y", 1.0,
-							 "opacity", 255,
-							 NULL);
-		}
-	}
-
-	return animation;
-}
-
 static void tangle_view_map(ClutterActor* actor) {
 	TangleView* view;
 	
@@ -213,7 +173,6 @@ static void tangle_view_dispose(GObject* object) {
 static void tangle_view_class_init(TangleViewClass* view_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(view_class);
 	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(view_class);
-	TangleActorClass* actor_class = TANGLE_ACTOR_CLASS(view_class);
 
 	gobject_class->finalize = tangle_view_finalize;
 	gobject_class->dispose = tangle_view_dispose;
@@ -222,8 +181,6 @@ static void tangle_view_class_init(TangleViewClass* view_class) {
 	
 	clutter_actor_class->map = tangle_view_map;
 
-	actor_class->animate_transition = tangle_view_animate_transition;
-
 	/**
 	 * TangleView:filename:
 	 */
