@@ -36,11 +36,16 @@ enum {
 	PROP_BACKGROUND_COLOR,
 	PROP_BACKGROUND_COLOR_SET,
 	PROP_BACKGROUND_ACTOR,
+	PROP_FOREGROUND_ACTOR,
 	PROP_PREFER_BACKGROUND_SIZE,
 	PROP_PREFER_BACKGROUND_SIZE_SET,
 	PROP_PICKABLE
 };
 
+enum {
+	PAINT_CHILDREN,
+	LAST_SIGNAL
+};
 struct _TangleWidgetPrivate {
 	GList* children;
 	TangleLayout* layout;
@@ -50,6 +55,7 @@ struct _TangleWidgetPrivate {
 
 	ClutterColor background_color;
 	ClutterActor* background_actor;
+	ClutterActor* foreground_actor;
 	
 	guint padding_set : 1;
 	guint background_color_set : 1;
@@ -58,6 +64,10 @@ struct _TangleWidgetPrivate {
 	guint pickable : 1;
 };
 
+static guint signals[LAST_SIGNAL] = { 0 };
+
+static void tangle_widget_get_preferred_width(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
+static void tangle_widget_get_preferred_height(TangleActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
 static void tangle_widget_add_impl(TangleWidget* container, ClutterActor* actor, ClutterActor* existing, gboolean before);
 static gboolean tangle_widget_unapply_stylesheet(TangleStylable* stylable, TangleStylesheet* stylesheet);
 static void change_actor_order(TangleWidget* widget, ClutterActor* actor, ClutterActor* sibling, gboolean before);
@@ -265,21 +275,81 @@ void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* acto
 	ClutterActorBox actor_box;
 
 	if (widget->priv->background_actor != actor) {
+		if (actor) {
+			g_object_ref_sink(actor);
+		}
 		if (widget->priv->background_actor) {
 			clutter_actor_unparent(widget->priv->background_actor);
 			g_object_unref(widget->priv->background_actor);
 		}
 		widget->priv->background_actor = actor;
-		g_object_ref_sink(widget->priv->background_actor);
 		
-		tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
-		clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
-		clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
+		if (actor) {
+			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
+			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
+			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
+		}
+		
 		g_object_notify(G_OBJECT(widget), "background-actor");
 		clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
 	}
 }
 
+/**
+ * tangle_widget_change_background_actor:
+ * @widget: a #TangleWidget
+ * @actor: a #TangleActor that is already parented and referenced by the widget
+ *
+ * This function changes the active background actor. Note that the given actor must be
+ * already parented and referenced by the widget itself! This function is meant to be used
+ * by subclasses of #TangleWidget (such as #TangleButton). Usually do not use this function.
+ * See tangle_widget_set_background_actor() instead.
+ */
+void tangle_widget_change_background_actor(TangleWidget* widget, ClutterActor* actor) {
+	ClutterActorBox actor_box;
+
+	if (widget->priv->background_actor != actor) {
+		widget->priv->background_actor = actor;
+		
+		if (actor) {
+			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
+			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
+		}
+		
+		g_object_notify(G_OBJECT(widget), "background-actor");
+		clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
+	}
+}
+
+ClutterActor* tangle_widget_get_foreground_actor(TangleWidget* widget) {
+
+	return widget->priv->foreground_actor;
+}
+
+void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* actor) {
+	ClutterActorBox actor_box;
+
+	if (widget->priv->foreground_actor != actor) {
+		if (actor) {
+			g_object_ref_sink(actor);
+		}
+		if (widget->priv->foreground_actor) {
+			clutter_actor_unparent(widget->priv->foreground_actor);
+			g_object_unref(widget->priv->foreground_actor);
+		}
+		widget->priv->foreground_actor = actor;
+		
+		if (actor) {
+			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
+			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
+			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
+		}
+		
+		g_object_notify(G_OBJECT(widget), "foreground-actor");
+		clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
+	}
+}
+
 gboolean tangle_widget_get_prefer_background_size(TangleWidget* widget) {
 
 	return widget->priv->prefer_background_size;
@@ -308,16 +378,80 @@ void tangle_widget_set_prefer_background_size_set(TangleWidget* widget, gboolean
 	}
 }
 
+void tangle_widget_get_real_preferred_size(TangleWidget* widget, gboolean interacting, gfloat* min_width_p, gfloat* min_height_p, gfloat* natural_width_p, gfloat* natural_height_p, gfloat* max_width_p, gfloat* max_height_p) {
+	ClutterRequestMode request_mode;
+	gfloat natural_size;
+	
+	g_object_get(widget, "request-mode", &request_mode, NULL);
+	if (request_mode == CLUTTER_REQUEST_HEIGHT_FOR_WIDTH) {
+		tangle_widget_get_real_preferred_width(widget, -1, interacting, min_width_p, &natural_size, max_width_p);
+		tangle_widget_get_real_preferred_height(widget, natural_size, interacting, min_height_p, natural_height_p, max_height_p);
+		if (natural_width_p) {
+			*natural_width_p = natural_size;
+		}
+	} else {
+		tangle_widget_get_real_preferred_height(widget, -1, interacting, min_height_p, &natural_size, max_height_p);
+		tangle_widget_get_real_preferred_width(widget, natural_size, interacting, min_width_p, natural_width_p, max_width_p);
+		if (natural_height_p) {
+			*natural_height_p = natural_size;
+		}
+	}
+}
+
+void tangle_widget_get_real_preferred_width(TangleWidget* widget, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p) {
+	tangle_widget_get_preferred_width(TANGLE_ACTOR(widget), for_height, interacting, min_width_p, natural_width_p, max_width_p);
+}
+
+void tangle_widget_get_real_preferred_height(TangleWidget* widget, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p) {
+	tangle_widget_get_preferred_height(TANGLE_ACTOR(widget), for_width, interacting, min_height_p, natural_height_p, max_height_p);
+}
+
+#define ABS_F(x) ((x) < 0 ? -(x) : (x))
+
+void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* clamp) {
+	gfloat original_value;
+	TangleClampDirection direction;
+	GList* child_in_list;
+	gfloat child_value;
+	gfloat child_distance;
+	gfloat clamp_distance = G_MAXFLOAT;
+	
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+	
+	original_value = tangle_clamp_get_original_value(clamp);
+	direction = tangle_clamp_get_direction(clamp);
+	
+	for (child_in_list = TANGLE_WIDGET(widget)->priv->children; child_in_list; child_in_list = child_in_list->next) {
+		if (direction == TANGLE_CLAMP_HORIZONTAL) {
+			child_value = clutter_actor_get_x(CLUTTER_ACTOR(child_in_list->data));
+		} else if (direction == TANGLE_CLAMP_VERTICAL) {
+			child_value = clutter_actor_get_y(CLUTTER_ACTOR(child_in_list->data));
+		} else {
+			continue;
+		}
+		if ((child_distance = ABS_F(child_value - original_value)) < clamp_distance) {
+			clamp_distance = child_distance;
+			tangle_clamp_set_clamped_value(clamp, child_value);
+		}
+	}
+}
+
 static void paint_actor_if_mapped(ClutterActor* actor) {
 	if (CLUTTER_ACTOR_IS_MAPPED(actor)) {
 		clutter_actor_paint(actor);
 	}
 }
 
+static void tangle_widget_paint_children(TangleWidget* widget) {
+	g_list_foreach(widget->priv->children, (GFunc)paint_actor_if_mapped, NULL);
+}
+
 static void tangle_widget_paint(ClutterActor* actor) {
 	TangleWidget* widget;
 	gdouble scale_x;
 	gdouble scale_y;
+	gfloat scale_center_x;
+	gfloat scale_center_y;
 	guint8 alpha;
 	ClutterActorBox box;
 	gboolean transition_scale_children;
@@ -326,9 +460,7 @@ static void tangle_widget_paint(ClutterActor* actor) {
 	transition_scale_children = tangle_actor_should_transition_scale_children(TANGLE_ACTOR(widget));
 
 	cogl_push_matrix();
-
-	g_object_get(actor, "transition-scale-x", &scale_x, "transition-scale-y", &scale_y, NULL);
-	cogl_scale(scale_x, scale_y, 1.0);
+	tangle_actor_apply_transition_scale(TANGLE_ACTOR(widget));
 
 	if (widget->priv->background_color_set) {
 		alpha = clutter_actor_get_paint_opacity(actor) * widget->priv->background_color.alpha / 255;
@@ -347,9 +479,18 @@ static void tangle_widget_paint(ClutterActor* actor) {
 		cogl_pop_matrix();
 	}
 
-	g_list_foreach(TANGLE_WIDGET(actor)->priv->children, (GFunc)paint_actor_if_mapped, NULL);
+	g_signal_emit(widget, signals[PAINT_CHILDREN], 0);
 
-	if (transition_scale_children) {
+	if (widget->priv->foreground_actor) {
+		if (!transition_scale_children) {
+			cogl_push_matrix();
+			tangle_actor_apply_transition_scale(TANGLE_ACTOR(widget));
+		}
+		
+		clutter_actor_paint(widget->priv->foreground_actor);
+		
+		cogl_pop_matrix();
+	} else if (transition_scale_children) {
 		cogl_pop_matrix();
 	}
 }
@@ -504,12 +645,33 @@ static void tangle_widget_get_preferred_height(TangleActor* actor, gfloat for_wi
 	}
 }
 
+static void tangle_widget_allocate_children(TangleWidget* widget, const ClutterActorBox* box, ClutterAllocationFlags flags) {
+	GList* child_in_children;
+	ClutterActor* child;
+	gfloat width, height;
+	ClutterActorBox actor_box;
+
+	if (widget->priv->layout) {
+		tangle_layout_allocate(widget->priv->layout, box, flags);
+	} else {
+		for (child_in_children = widget->priv->children; child_in_children; child_in_children = child_in_children->next) {
+			child = CLUTTER_ACTOR(child_in_children->data);
+			if (CLUTTER_ACTOR_IS_VISIBLE(child)) {
+				clutter_actor_get_preferred_size(child, NULL, NULL, &width, &height);
+				actor_box.x1 = box->x1 + clutter_actor_get_x(child);
+				actor_box.y1 = box->y1 + clutter_actor_get_y(child);
+				actor_box.x2 = actor_box.x1 + width;
+				actor_box.y2 = actor_box.y1 + height;
+				clutter_actor_allocate(child, &actor_box, flags);
+			}
+		}
+	}
+}
+
 static void tangle_widget_allocate(ClutterActor* actor, const ClutterActorBox* box, ClutterAllocationFlags flags) {
 	TangleWidget* widget;
 	ClutterActorBox actor_box;
 	ClutterActorBox old_children_allocation;
-	GList* child_in_children;
-	ClutterActor* child;
 
 	widget = TANGLE_WIDGET(actor);
 
@@ -519,6 +681,10 @@ static void tangle_widget_allocate(ClutterActor* actor, const ClutterActorBox* b
 		tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &actor_box);
 		clutter_actor_allocate(widget->priv->background_actor, &actor_box, flags);
 	}
+	if (widget->priv->foreground_actor) {
+		tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &actor_box);
+		clutter_actor_allocate(widget->priv->foreground_actor, &actor_box, flags);
+	}
 
 	old_children_allocation = widget->priv->children_allocation;
 	tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &widget->priv->children_allocation);
@@ -532,16 +698,7 @@ static void tangle_widget_allocate(ClutterActor* actor, const ClutterActorBox* b
 		g_object_notify(G_OBJECT(actor), "children-allocation");
 	}
 
-	if (widget->priv->layout) {
-		tangle_layout_allocate(widget->priv->layout, &widget->priv->children_allocation, flags);
-	} else {
-		for (child_in_children = widget->priv->children; child_in_children; child_in_children = child_in_children->next) {
-			child = CLUTTER_ACTOR(child_in_children->data);
-			if (CLUTTER_ACTOR_IS_VISIBLE(child)) {
-				clutter_actor_allocate_preferred_size(child, flags);
-			}
-		}
-	}
+	TANGLE_WIDGET_GET_CLASS(actor)->allocate_children(widget, &widget->priv->children_allocation, flags);
 }
 
 static void tangle_widget_map(ClutterActor* actor) {
@@ -560,6 +717,9 @@ static void tangle_widget_map(ClutterActor* actor) {
 	if (widget->priv->background_actor) {
 		clutter_actor_map(widget->priv->background_actor);
 	}
+	if (widget->priv->foreground_actor) {
+		clutter_actor_map(widget->priv->foreground_actor);
+	}
 }
 
 static void tangle_widget_handle_ancestor_event(TangleActor* actor, TangleEvent* event) {
@@ -583,6 +743,9 @@ static void tangle_widget_set_property(GObject* object, guint prop_id, const GVa
 		case PROP_BACKGROUND_ACTOR:
 			tangle_widget_set_background_actor(widget, CLUTTER_ACTOR(g_value_get_object(value)));
 			break;
+		case PROP_FOREGROUND_ACTOR:
+			tangle_widget_set_foreground_actor(widget, CLUTTER_ACTOR(g_value_get_object(value)));
+			break;
 		case PROP_PREFER_BACKGROUND_SIZE:
 			tangle_widget_set_prefer_background_size(widget, g_value_get_boolean(value));
 			break;
@@ -616,6 +779,9 @@ static void tangle_widget_get_property(GObject* object, guint prop_id, GValue* v
 		case PROP_BACKGROUND_ACTOR:
 			g_value_set_object(value, tangle_widget_get_background_actor(widget));
 			break;
+		case PROP_FOREGROUND_ACTOR:
+			g_value_set_object(value, tangle_widget_get_foreground_actor(widget));
+			break;
 		case PROP_PREFER_BACKGROUND_SIZE:
 			g_value_set_boolean(value, widget->priv->prefer_background_size);
 			break;
@@ -637,7 +803,7 @@ static void tangle_widget_dispose(GObject* object) {
 	widget = TANGLE_WIDGET(object);
 	
 	if (widget->priv->children) {
-		g_list_foreach(widget->priv->children, (GFunc)clutter_actor_destroy, NULL);
+		g_list_foreach(widget->priv->children, (GFunc)clutter_actor_unparent, NULL);
 		g_list_free(widget->priv->children);
 		widget->priv->children = NULL;
 	}
@@ -655,6 +821,11 @@ static void tangle_widget_dispose(GObject* object) {
 		g_object_unref(widget->priv->background_actor);
 		widget->priv->background_actor = NULL;
 	}
+	if (widget->priv->foreground_actor) {
+		clutter_actor_unparent(widget->priv->foreground_actor);
+		g_object_unref(widget->priv->foreground_actor);
+		widget->priv->foreground_actor = NULL;
+	}
 
 	G_OBJECT_CLASS(tangle_widget_parent_class)->dispose(object);
 }
@@ -677,6 +848,9 @@ static void tangle_widget_class_init(TangleWidgetClass* widget_class) {
 	actor_class->get_preferred_height = tangle_widget_get_preferred_height;
 	actor_class->handle_ancestor_event = tangle_widget_handle_ancestor_event;
 
+	widget_class->paint_children = tangle_widget_paint_children;
+	widget_class->allocate_children = tangle_widget_allocate_children;
+
 	/**
 	 * TangleWidget:layout:
 	 */
@@ -722,6 +896,15 @@ static void tangle_widget_class_init(TangleWidgetClass* widget_class) {
 	                                "The actor that is used as a background of the widget",
 	                                CLUTTER_TYPE_ACTOR,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleWidget:foreground-actor:
+	 */
+	g_object_class_install_property(gobject_class, PROP_FOREGROUND_ACTOR,
+	                                g_param_spec_object("foreground-actor",
+	                                "Foreground actor",
+	                                "The actor that is used as a foreground of the widget",
+	                                CLUTTER_TYPE_ACTOR,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleWidget:prefer-background-size:
 	 *
@@ -769,6 +952,14 @@ static void tangle_widget_class_init(TangleWidgetClass* widget_class) {
 	                                TRUE,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
+	signals[PAINT_CHILDREN] = g_signal_new("paint-children",
+	                                       G_TYPE_FROM_CLASS(gobject_class),
+					       G_SIGNAL_RUN_LAST,
+					       G_STRUCT_OFFSET(TangleWidgetClass, paint_children),
+					       NULL, NULL,
+					       g_cclosure_marshal_VOID__VOID,
+					       G_TYPE_NONE, 0);
+
 	g_type_class_add_private(gobject_class, sizeof(TangleWidgetPrivate));
 }
 
