@@ -32,6 +32,9 @@ struct _TangleWidget {
 
 struct _TangleWidgetClass {
 	TangleActorClass parent_class;
+	
+	void (*allocate_children)(TangleWidget* widget, const ClutterActorBox* box, ClutterAllocationFlags flags);
+	void (*paint_children)(TangleWidget* widget);
 };
 
 typedef void (*TangleSwappedCallback)(gpointer data, ClutterActor* actor);
@@ -41,6 +44,7 @@ GType tangle_widget_get_type(void) G_GNUC_CONST;
 
 #include "tangle-style.h"
 #include "tangle-layout.h"
+#include "tangle-clamp.h"
 
 ClutterActor* tangle_widget_new(void);
 ClutterActor* tangle_widget_new_with_layout(TangleLayout* layout);
@@ -73,12 +77,20 @@ void tangle_widget_set_background_color(TangleWidget* widget, const ClutterColor
 
 ClutterActor* tangle_widget_get_background_actor(TangleWidget* widget);
 void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* actor);
+void tangle_widget_change_background_actor(TangleWidget* widget, ClutterActor* actor);
+
+ClutterActor* tangle_widget_get_foreground_actor(TangleWidget* widget);
+void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* actor);
 
 gboolean tangle_widget_get_prefer_background_size(TangleWidget* widget);
 void tangle_widget_set_prefer_background_size(TangleWidget* widget, gboolean prefer_background_size);
 gboolean tangle_widget_get_prefer_background_size_set(TangleWidget* widget);
 void tangle_widget_set_prefer_background_size_set(TangleWidget* widget, gboolean is_set);
 
+void tangle_widget_get_real_preferred_size(TangleWidget* widget, gboolean interacting, gfloat* min_width_p, gfloat* min_height_p, gfloat* natural_width_p, gfloat* natural_height_p, gfloat* max_width_p, gfloat* max_height_p);
+void tangle_widget_get_real_preferred_width(TangleWidget* widget, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
+void tangle_widget_get_real_preferred_height(TangleWidget* widget, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
 
+void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* clamp);
 
 #endif
