@@ -13,22 +13,28 @@
 
 #include "tangle-action.h"
 #include "tangle-actor.h"
+#include "tangle-apply-template-action.h"
 #include "tangle-binding.h"
 #include "tangle-box-layout.h"
 #include "tangle-button.h"
 #include "tangle-call-function-action.h"
+#include "tangle-clamp.h"
 #include "tangle-compound-style.h"
+#include "tangle-curved-transition.h"
 #include "tangle-draggable-actor.h"
 #include "tangle-droppable-actor.h"
+#include "tangle-easing-transition.h"
 #include "tangle-event.h"
 #include "tangle-floating-actor.h"
 #include "tangle-grid.h"
 #include "tangle-layout.h"
 #include "tangle-layout-meta.h"
 #include "tangle-linear-gradient.h"
+#include "tangle-multiplexed-transition.h"
 #include "tangle-misc.h"
 #include "tangle-properties.h"
 #include "tangle-scrollbar.h"
+#include "tangle-scroller.h"
 #include "tangle-scrolling-actor.h"
 #include "tangle-set-property-action.h"
 #include "tangle-show-actor-action.h"
@@ -38,6 +44,7 @@
 #include "tangle-stylesheet.h"
 #include "tangle-timeline.h"
 #include "tangle-template.h"
+#include "tangle-transition.h"
 #include "tangle-vault.h"
 #include "tangle-view.h"
 #include "tangle-warehouse.h"
